#!/usr/bin/env python

from distutils.core import setup

setup( name='see',
       version='1.1.0',
       description='A human-readable alternative to dir',
       author='Liam Cooke',
       author_email='hi@liamcooke.com',
       url='http://inky.github.io/see/',
       py_modules=['see'],
       classifiers=[
           'Development Status :: 4 - Beta',
           'Environment :: Console',
           'Intended Audience :: Developers',
           'License :: Freely Distributable',
           'License :: OSI Approved :: BSD License',
           'Natural Language :: English',
           'Operating System :: OS Independent',
           'Programming Language :: Python',
           'Topic :: Software Development',
       ])
